#
# spec file for package python
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname aci-integration-module
%define skip_python3 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-%{sname}
Version:        0.14.3
Release:        4.2
Summary:        Python library for programming ACI
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://github.com/noironetworks/aci-integration-module
Source:         https://github.com/noironetworks/aci-integration-module/archive/%{version}.tar.gz
BuildRequires:  %{python_module acitoolkit >= 0.3.2}
BuildRequires:  %{python_module click >= 3.3}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module oslo.concurrency}
BuildRequires:  %{python_module oslo.config}
BuildRequires:  %{python_module oslo.db}
BuildRequires:  %{python_module oslo.log}
BuildRequires:  %{python_module oslo.messaging}
BuildRequires:  %{python_module oslo.utils}
BuildRequires:  %{python_module oslotest >= 1.10.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module python-subunit >= 0.0.18}
BuildRequires:  %{python_module semantic_version}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tabulate >= 0.7.5}
BuildRequires:  %{python_module websocket-client}
BuildRequires:  fdupes
BuildRequires:  logrotate
BuildRequires:  python-apicapi
BuildRequires:  python-rpm-macros
Requires:       logrotate
Requires:       python-acitoolkit >= 0.3.2
Requires:       python-alembic
Requires:       python-apicapi
Requires:       python-click >= 3.3
Requires:       python-jsonschema
Requires:       python-kubernetes
Requires:       python-oslo.concurrency
Requires:       python-oslo.config
Requires:       python2-oslo.db
Requires:       python-oslo.log
Requires:       python2-oslo.messaging
Requires:       python-oslo.utils
Requires:       python-semantic_version
Requires:       python-tabulate >= 0.7.5
Requires:       python-websocket-client
BuildArch:      noarch
%python_subpackages

%description
Module to bring together libraries and tools for integrating ACI with cloud.

%prep
%setup -q -n %{sname}-%{version}

%build
export PBR_VERSION=%{version}
%python_build

%install
export PBR_VERSION=%{version}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
install -p -D -m 0644 rpm/aim-aid.service %{buildroot}/%{_unitdir}/aim-aid.service
install -p -D -m 0644 rpm/aim-event-service-polling.service %{buildroot}/%{_unitdir}/aim-event-service-polling.service
install -p -D -m 0644 rpm/aim-event-service-rpc.service %{buildroot}/%{_unitdir}/aim-event-service-rpc.service
mkdir -p %{buildroot}/run/aid/events
# Install logrotate
install -p -D -m 0644 etc/logrotate.d/aim %{buildroot}%{_sysconfdir}/logrotate.d/aim

# Remove unused files
%python_expand rm -rf %{buildroot}%{$python_sitelib}/aim/tests

# Move files to the expected locations
mv %{buildroot}%{_prefix}%{_sysconfdir}/aim/  %{buildroot}%{_sysconfdir}

%check
export LANG=en_US.UTF-8
# TODO: unfortunatly the tests require runing APIC server
#%%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m subunit.run discover

%pre
%service_add_pre aim-aid.service aim-event-service-polling.service aim-event-service-rpc.service

%post
%service_add_post aim-aid.service aim-event-service-polling.service aim-event-service-rpc.service

%preun
%service_del_preun aim-aid.service aim-event-service-polling.service aim-event-service-rpc.service

%postun
%service_del_postun aim-aid.service aim-event-service-polling.service aim-event-service-rpc.service

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/aim
%{python_sitelib}/aci_integration_module-*.egg-info
%{_bindir}/aimctl
%{_bindir}/aimdebug
%{_bindir}/aim-aid
%{_bindir}/aim-event-service-polling
%{_bindir}/aim-event-service-rpc
%{_bindir}/aim-http-server
%config(noreplace) %{_sysconfdir}/aim/aim.conf
%config(noreplace) %{_sysconfdir}/aim/aimctl.conf
%{_unitdir}/aim-aid.service
%{_unitdir}/aim-event-service-polling.service
%{_unitdir}/aim-event-service-rpc.service
%ghost /run/aid
%ghost /run/aid/events
%dir %{_sysconfdir}/aim
%config(noreplace) %{_sysconfdir}/logrotate.d/*

%changelog
* Mon Nov 12 2018 sma@suse.com
- Modified the .spec file to build only the python2 package.
* Wed Oct 24 2018 sma@suse.com
- Fixed up the SPEC file so that the build can succeed with the
  upstream tarball. Otherwise, the tarball needs to be generated
  from the "python setup.py sdist" command.
* Wed Oct 24 2018 tchvatal@suse.com
- Switch to the upstream tarball as is required by our policies
* Wed Oct 24 2018 tchvatal@suse.com
- Remove useless patch 0001_manifest_alembic_addition.patch
- Do not remove requirements file in the prep phase
- Specify the package group
- Make sure we execute unittests, for now skipped
- Format the spec file using spec-cleaner to get unified look and
  normal whitespace
- Changelog should be named the same as spec-file
- Changelog should be in an order timewise
- Changelog should not contain any patch lines
* Mon Oct 22 2018 mmnelemane@suse.com
- Added a patch to include alembic migration files
* Mon Oct 22 2018 dmueller@suse.com
- run format-spec file and fix requires
* Thu Oct 18 2018 sma@suse.com
- Spec file changes:
  - Added the LICENSE file to the package.
  - Synced the Requires list with requirements.txt.
  - Eliminated the RPMlint error on duplicate files.
  - Eliminated as many RPMlint warnings as possible.
* Thu Oct 18 2018 sma@suse.com
- Renamed aci-integration-module to python-aci-integration-module.
  Thus renamed the spec file. And made the spec file singlespec.
* Thu Oct 18 2018 mmnelemane@suse.com
- Built source package directly from source
  - removed manual steps for the build
  - Upgraded to version 0.14.3
* Tue Oct 16 2018 sma@suse.com
- Change the .spec file to build python-aci-integration-module
  * Made it conform to singlespec standards, but only build python2
    packages.
  * made other cleanups to the spec file.
* Mon Oct 15 2018 sma@suse.com
- Corrected spelling in spec file: python-sqlalchemy should be
  python-SQLAlchemy.
* Wed Oct 10 2018 sma@suse.com
- License should be Apache-2.0 according to the LICENSE file
  in the aci-integration-module-0.10.0.tar.gz.
* Tue Jun 26 2018 mmnelemane@suse.com
- Upgraded to 0.10.0
  - for use with openstack Pike
* Thu Dec 21 2017 mmnelemane@suse.com
- Fixed Requires python-acitoolkit
* Thu Dec 21 2017 mmnelemane@suse.com
- Fixed Requires for python-oslo.config
* Fri Aug 25 2017 mmnelemane@suse.com
- Initial Packaging (version 0.3.0)
